@@ -4,7 +4,8 @@ Converts links between notebooks to Latex cross-references.
 """
 import re
 
-from pandocfilters import RawInline, applyJSONFilters
+from pandocfilters import RawInline, applyJSONFilters, stringify  # type:ignore
+
 
 def resolve_references(source):
     """
@@ -15,24 +16,26 @@ def resolve_references(source):
     """
     return applyJSONFilters([resolve_one_reference], source)
 
+
 def resolve_one_reference(key, val, fmt, meta):
     """
     This takes a tuple of arguments that are compatible with ``pandocfilters.walk()`` that
-    allows identifying hyperlinks in the document and transforms them into valid LaTeX 
-    \\ref{} calls so that linking to headers between cells is possible.
+    allows identifying hyperlinks in the document and transforms them into valid LaTeX
+    \\hyperref{} calls so that linking to headers between cells is possible.
 
     See the documentation in ``pandocfilters.walk()`` for further information on the meaning
-    and specification of ``key``, ``val``, ``fmt``, and ``meta``. 
+    and specification of ``key``, ``val``, ``fmt``, and ``meta``.
     """
-    
-    if key == 'Link':
+
+    if key == "Link":
+        text = stringify(val[1])
         target = val[2][0]
-        m = re.match(r'#(.+)$', target)
+        m = re.match(r"#(.+)$", target)
         if m:
             # pandoc automatically makes labels for headings.
             label = m.group(1).lower()
-            label = re.sub(r'[^\w-]+', '', label) # Strip HTML entities
-            return RawInline('tex', r'Section \ref{%s}' % label)
+            label = re.sub(r"[^\w-]+", "", label)  # Strip HTML entities
+            text = re.sub(r"_", r"\_", text)  # Escape underscores in display text
+            return RawInline("tex", rf"\hyperref[{label}]{{{text}}}")
 
     # Other elements will be returned unchanged.
-
